import { AbstractMachine, FetchMachine, FetchMachineEvent, Machine } from '@genesislcap/foundation-state-machine';
import { UUID } from '@genesislcap/foundation-utils';
import type { InterpreterOptions } from 'xstate';
import { AuthConfig } from '../config/config';
import { CredentialManager } from '../credential';
import { AuthMessageMapper } from '../mapper';
import { AuthRouting } from '../routes/routing';
import { User } from '../user';
import type { AuthMachineContext, AuthMachineEvent, LoginParams, QueryParams } from './types';
/**
 * AuthMachine interface.
 * @public
 */
export interface AuthMachine extends Machine<AuthMachineContext, AuthMachineEvent> {
}
/**
 * Default AuthMachine.
 * @public
 */
export declare class DefaultAuthMachine extends AbstractMachine<AuthMachineContext, AuthMachineEvent> implements AuthMachine {
    private user;
    private fetchMachine;
    private cm;
    private uuid;
    private messageMapper;
    private config;
    private routing;
    constructor(user: User, fetchMachine: FetchMachine, cm: CredentialManager, uuid: UUID, messageMapper: AuthMessageMapper, config: AuthConfig, routing: AuthRouting);
    start(options?: InterpreterOptions<typeof this.machine>): void;
    /**
     * AuthMachine is a singleton.
     */
    getFromContainer(): this;
    protected captureAuthQueryParams(): QueryParams;
    protected convertQueryParamsToLoginParams(params: QueryParams): LoginParams;
    protected createFetchMachineEvent(url: string, msg?: {}): FetchMachineEvent;
    protected onIdleEvents: () => {
        login: {
            actions: string[];
            target: string;
        };
        "forgot-password": {
            actions: string[];
            target: string;
        };
        "change-password": {
            actions: string[];
            target: string;
        };
        "reset-password": {
            actions: string[];
            target: string;
        };
    };
    protected onDoneDTO: () => {
        actions: string[];
        target: string;
    };
}
/**
 * AuthMachine DI key.
 * @internal
 */
export declare const AuthMachine: import("@microsoft/fast-foundation").InterfaceSymbol<AuthMachine>;
//# sourceMappingURL=machine.d.ts.map