import { __awaiter } from "tslib";
import { ResourceType } from '@genesislcap/foundation-utils';
import { logger } from '../utils';
/**
 * zeroDesignSystemImport.
 * @remarks
 * Attempts to use a module federation version of zero before falling back to the version that was bundled with the app.
 * @internal
 */
function zeroDesignSystemImport() {
    return __awaiter(this, void 0, void 0, function* () {
        let type = ResourceType.remote;
        try {
            return yield import(
            /* webpackChunkName: "foundation-zero" */
            'foundationZero/ZeroDesignSystem');
        }
        catch (e) {
            logger.info(`Please note remoteEntry.js load errors are expected if module federated dependencies are offline. Falling back to locally bundled versions.`);
            type = ResourceType.local;
            return yield import(
            /* webpackChunkName: "foundation-zero" */
            '@genesislcap/foundation-zero');
        }
        finally {
            logger.debug(`Using '${type}' version of foundation-zero`);
        }
    });
}
/**
 * registerCommonZeroComponents.
 * @public
 */
export const registerCommonZeroComponents = () => __awaiter(void 0, void 0, void 0, function* () {
    const { provideDesignSystem, zeroAnchor, zeroButton, zeroCard, zeroCheckbox, zeroDesignSystemProvider, zeroListboxOption, zeroProgressRing, zeroSelect, zeroTextField, } = yield zeroDesignSystemImport();
    /**
     * Register the components the app is using with the system.
     */
    provideDesignSystem().register(
    /**
     * Design system provider element used to declaratively apply zero config to every dom node in the host tree.
     */
    zeroDesignSystemProvider(), 
    /**
     * Common across most routes, so batch register these lightweight components upfront.
     */
    zeroAnchor(), zeroButton(), zeroCard(), zeroCheckbox(), zeroListboxOption(), zeroProgressRing(), zeroSelect(), zeroTextField());
});
