import { css } from '@microsoft/fast-element';
import { DI } from '@microsoft/fast-foundation';
import defaultBackgroundSrc from '../assets/bg.jpg';
import defaultLogoSrc from '../assets/genesis-logo-light.svg';
import { getRoutePath, navigateTo } from '../routes/utils';
import { defaultTemplateOptions } from './templates';
/**
 * Default AuthConfig DI implementation.
 * @public
 */
export const defaultAuthConfig = {
    name: 'foundation-auth',
    templateOptions: defaultTemplateOptions,
    logo: css `
    content: url(${defaultLogoSrc});
  `,
    background: css `
    :host {
      background-image: url(${defaultBackgroundSrc});
    }
  `,
    backgroundVideo: null,
    omitRoutes: [],
    fields: {
        organisation: null,
        username: {
            label: 'Username',
            pattern: '^[a-zA-Z0-9.@_\\-]*$',
            title: 'Letters, numbers, and limited special characters @ _ - .',
        },
        email: {
            label: 'Email Address',
        },
        password: {
            label: 'Password',
        },
    },
    hostPath: '',
    forgotPasswordReturnUrl: `${location.protocol}//${location.host}/${getRoutePath('reset-password')}`,
    omitRedirectUrls: ['/not-found', '/not-permitted'],
    postLoginRedirect: () => navigateTo('protected'),
    postLogoutRedirect: () => navigateTo('/'),
    sso: {
        identityProvidersPath: 'gwf/sso/list',
    },
    feedbackDelay: 3000,
};
/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const AuthConfig = DI.createInterface((x) => x.instance(defaultAuthConfig));
