import { __decorate } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { AuthConfig } from '../config/config';
import { getRoutePath, navigateTo } from './utils';
/**
 * Default AuthRouting.
 *
 * @public
 */
export class DefaultAuthRouting {
    /** {@inheritDoc AuthRouting.navigateTo} */
    navigateTo(route) {
        navigateTo(this.getRoutePath(route));
    }
    /** {@inheritDoc AuthRouting.getRoutePath} */
    getRoutePath(route) {
        return getRoutePath(route, this.config.hostPath);
    }
}
__decorate([
    AuthConfig
], DefaultAuthRouting.prototype, "config", void 0);
/**
 * AuthRouting DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const AuthRouting = DI.createInterface((x) => x.singleton(DefaultAuthRouting));
/**
 * Gets AuthRouting from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getAuthRouting } from '@genesislcap/foundation-auth/routing';
 * ...
 * private authRouting = getAuthRouting();
 * ...
 * this.authRouting.navigateTo('logout');
 * ```
 *
 * @public
 */
export function getAuthRouting() {
    return DI.getOrCreateDOMContainer().get(AuthRouting);
}
